; ============================================================================
; "WMAP_Read_NInv" reads a WMAP N-Inverse FITS file.
;
; This procedure requires the IDL Astronomy Users Library, available from
; http://idlastro.gsfc.nasa.gov/
;
; Input Arguments:
;	File      - The name of the file.
;
; Output Arguments:
;	NInv      - The square N-inverse array.
;
; Output Keyword Arguments:
;	NElements - The number of elements on each side of NInv.
;	NPixels   - The number of pixels in the maps that N-inverse applies
;	            to.  This extracted from either the NPIX or LASTPIX 
;	            keywords in the primary header; if neither is found then
;	            zero is returned.
;
; Written by Michael R. Greason, SSAI, 13 March 2006.
; ============================================================================
Pro WMAP_Read_NInv, File, NInv, NElements=nele, NPixels=npix
;
on_error, 2
;
;			Check arguments.
;
If (n_params() LT 2) Then message, 'Syntax:  WMAP_Read_NInv, File, NInv'
;
;			Read the file.
;
NInv = mrdfits(File, 0, phdr, /Silent)
;
;			Fill the keywords.  Start by looking at the NPIX
;			keyword; if that isn't found, use LASTPIX.  If
;			neither is found, give up!
;
sz   = size(NInv)
nele = sz[1]
;
npix = sxpar(phdr, 'NPIX', Count=cnt)
If (!ERR EQ -1) Then Begin
  npix = sxpar(phdr, 'LASTPIX', Count=cnt) + 1
  If (!ERR EQ -1) Then npix = 0
EndIf
;
Return
End
